/*#############################################################################
#                                                                             #
#                                log_check                                    #
#    Copyright (c) 2002 David TAILLANDIER / Michel CARAMEZ / SOLEIL-VERT      #
#                                                                             #
#############################################################################*/

/*
History :
v0.93 june 10th 2002  David TAILLANDIER -- SOLEIL VERT
     added the choice between "message" and "buton" mode
     now close gracefully with 'end-of-task' in task manager
v0.92 april 8th 2002  David TAILLANDIER -- SOLEIL VERT
     "OK" button removed because some (stupid) people don't read the message
     and try to use the computer
v0.91 february 8th 2002  David TAILLANDIER -- SOLEIL VERT
     rewritten in C
v0.9 february  5th 2002  Michel CARAMEZ -- SOLEIL VERT
     initial release   Written in Visual Basic

*/

/*###########################################################################*/

#define STRICT

#include <windows.h>
#include <commctrl.h>

#define err_exit(text)  {MessageBox(NULL,text,"log_check error",MB_ICONEXCLAMATION|MB_OK);ExitProcess(-1);}
void usage( void );
void check_win9x( void );
char get_cmd_line( const char * cmdline );
BOOL APIENTRY dialog_proc( HWND hwndDlg, UINT message, WPARAM wParam, LPARAM lParam);

/*############################### winmain ###################################*/
#pragma argsused
int WINAPI
WinMain( HINSTANCE hInstance,
         HINSTANCE unused1,
         PSTR cmdline,
         int unused2
       )
{
     int   mode;
     char  dummy[64];
     DWORD dummy_size;

     check_win9x();
     mode = get_cmd_line( cmdline );

     dummy_size = sizeof( dummy );
     if ( GetUserName(dummy,&dummy_size) == TRUE )
          return 0;
  
     if ( mode == 'm' )
          DialogBox( hInstance, MAKEINTRESOURCE(1), NULL, dialog_proc );

     if ( mode == 'b' )
          DialogBox( hInstance, MAKEINTRESOURCE(2), NULL, dialog_proc );

     return 1;
}

/*################################# dialog_proc #############################*/
#pragma argsused
BOOL APIENTRY dialog_proc( HWND hwndDlg,
                           UINT message,
                           WPARAM wParam,
                           LPARAM lParam)
{
     switch (message)
       {
          case WM_COMMAND: if ( LOWORD(wParam)==IDCANCEL || HIWORD(wParam)==BN_CLICKED )
                             {
                                EndDialog( hwndDlg, wParam );
                                return TRUE;
                             }
       }

     return FALSE;
}

/*############################## get_cmd_line ###############################*/
char
get_cmd_line( const char * cmdline )
{
     while( *cmdline==' ' || *cmdline=='\t' )
          cmdline++;

     switch ( *cmdline )
       {
          case 's':
          case 'S':   return 's';
          case 'm':
          case 'M':   return 'm';
          case 'b':
          case 'B':   return 'b';
       }

    usage();
    return 0;    /* never reached */
}

/*######################### check_win9x #####################################*/
/* exit(0) if not running Windows 95 or 98, else just return to caller       */
void
check_win9x( void )
{
     OSVERSIONINFO osver;

     // Get the current OS version
     osver.dwOSVersionInfoSize = sizeof(osver);
     if ( GetVersionEx(&osver) == 0 )
          err_exit( "Can't get OS version\nRuns only on Windows 95 / 98" );

     if (osver.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS)
         return;

     if (osver.dwPlatformId == VER_PLATFORM_WIN32_NT)
          err_exit( "Can't run on Windows NT\nRuns only on Windows 95 / 98" );

     err_exit( "Runs only on Windows 95 / 98" );

     return;
}

/*################################ usage ####################################*/
void
usage( void )
{
     err_exit( "log_check v0.92   Copyright (c) 2002 David TAILLANDIER / Michel CARAMEZ / SOLEIL VERT\n"
               "\n"
               "This small utility is intended to be launched in start menu or 'run' key into the registery.\n"
               "Works only on Windows 95/98/Me. If the user is logged on, nothing appens (return value=0).\n"
               "If the user is not logged, a message can be displayed (return value=1)\n"
               "\n"
               "usage:   log_check s        silent mode\n"
               "      or:   log_check m        message mode\n"
               "      or:   log_check b        message mode with close buton\n"
               "\n"
               "\n"
               "This program is free software; you can redistribute it and/or\n"
               "modify it under the terms of the GNU General Public License\n"
               "as published by the Free Software Foundation; either version 2\n"
               "of the License, or (at your option) any later version.\n"
               "\n"
               "This program is distributed in the hope that it will be useful,\n"
               "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
               "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
               "GNU General Public License for more details.\n"
               "\n"
               "You should have received a copy of the GNU General Public License\n"
               "along with this program; if not, write to the Free Software\n"
               "Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.\n"
               "\n"
               );
}

/*############################## END OF FILE ################################*/



